@@ -29,7 +29,6 @@ except ImportError:
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import timeutils
-import six
 
 from manila import db
 from manila import exception
@@ -147,6 +146,7 @@ class HostState(object):
         self.replication_domain = None
         self.ipv4_support = None
         self.ipv6_support = None
+        self.security_service_update_support = False
 
         # PoolState for all pools
         self.pools = {}
@@ -336,6 +336,10 @@ class HostState(object):
             pool_cap['sg_consistent_snapshot_support'] = (
                 self.sg_consistent_snapshot_support)
 
+        if 'security_service_update_support' not in pool_cap:
+            pool_cap['security_service_update_support'] = (
+                self.security_service_update_support)
+
         if self.ipv4_support is not None:
             pool_cap['ipv4_support'] = self.ipv4_support
 
@@ -365,6 +369,8 @@ class HostState(object):
             self.ipv4_support = capability['ipv4_support']
         if capability.get('ipv6_support') is not None:
             self.ipv6_support = capability['ipv6_support']
+        self.security_service_update_support = capability.get(
+            'security_service_update_support', False)
 
     def consume_from_share(self, share):
         """Incrementally update host state from an share."""
@@ -373,11 +379,11 @@ class HostState(object):
 
         self.allocated_capacity_gb += share['size']
 
-        if (isinstance(self.free_capacity_gb, six.string_types)
+        if (isinstance(self.free_capacity_gb, str)
                 and self.free_capacity_gb != 'unknown'):
             raise exception.InvalidCapacity(
                 name='free_capacity_gb',
-                value=six.text_type(self.free_capacity_gb)
+                value=self.free_capacity_gb
             )
 
         if self.free_capacity_gb != 'unknown':
@@ -461,6 +467,8 @@ class PoolState(HostState):
                 'replication_domain')
             self.sg_consistent_snapshot_support = capability.get(
                 'sg_consistent_snapshot_support')
+            self.security_service_update_support = capability.get(
+                'security_service_update_support', False)
 
     def update_pools(self, capability):
         # Do nothing, since we don't have pools within pool, yet
@@ -559,7 +567,8 @@ class HostManager(object):
                                                        hosts,
                                                        weight_properties)
 
-    def update_service_capabilities(self, service_name, host, capabilities):
+    def update_service_capabilities(self, service_name, host,
+                                    capabilities, timestamp):
         """Update the per-service capabilities based on this notification."""
         if service_name not in ('share',):
             LOG.debug('Ignoring %(service_name)s service update '
@@ -569,7 +578,15 @@ class HostManager(object):
 
         # Copy the capabilities, so we don't modify the original dict
         capability_copy = dict(capabilities)
-        capability_copy["timestamp"] = timeutils.utcnow()  # Reported time
+        timestamp = timestamp or timeutils.utcnow()
+        capability_copy["timestamp"] = timestamp  # Reported time
+
+        capab_old = self.service_states.get(host, {"timestamp": 0})
+        # Ignore older updates
+        if capab_old['timestamp'] and timestamp < capab_old['timestamp']:
+            LOG.info('Ignoring old capability report from %s.', host)
+            return
+
         self.service_states[host] = capability_copy
 
         LOG.debug("Received %(service_name)s service update from "
