@@ -40,6 +40,7 @@ EAPINOTFOUND = '13005'
 ESNAPSHOTNOTALLOWED = '13023'
 EVOLUMEOFFLINE = '13042'
 EINTERNALERROR = '13114'
+EINVALIDINPUTERROR = '13115'
 EDUPLICATEENTRY = '13130'
 EVOLNOTCLONE = '13170'
 EVOLMOVE_CANNOT_MOVE_TO_CFO = '13633'
@@ -57,6 +58,9 @@ EANOTHER_OP_ACTIVE = '17131'
 ERELATION_NOT_QUIESCED = '17127'
 ESOURCE_IS_DIFFERENT = '17105'
 EVOL_CLONE_BEING_SPLIT = '17151'
+EPOLICYNOTFOUND = '18251'
+EEVENTNOTFOUND = '18253'
+ESCOPENOTFOUND = '18259'
 ESVMDR_CANNOT_PERFORM_OP_FOR_STATUS = '18815'
 
 
