@@ -15,12 +15,11 @@
 
 import copy
 import datetime
+from unittest import mock
 
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-import six
 import webob
 
 from manila.api import common
@@ -117,11 +116,11 @@ class ShareAPITest(test.TestCase):
             'is_public': False,
             'links': [
                 {
-                    'href': 'http://localhost/v1/fake/shares/1',
+                    'href': 'http://localhost/share/v1/fake/shares/1',
                     'rel': 'self'
                 },
                 {
-                    'href': 'http://localhost/fake/shares/1',
+                    'href': 'http://localhost/share/fake/shares/1',
                     'rel': 'bookmark'
                 }
             ],
@@ -143,7 +142,7 @@ class ShareAPITest(test.TestCase):
     def test_share_create_original(self, microversion):
         self.mock_object(share_api.API, 'create', self.create_mock)
         body = {"share": copy.deepcopy(self.share)}
-        req = fakes.HTTPRequest.blank('/shares', version=microversion)
+        req = fakes.HTTPRequest.blank('/fake/shares', version=microversion)
 
         res_dict = self.controller.create(req, body)
 
@@ -157,7 +156,7 @@ class ShareAPITest(test.TestCase):
     def test_share_create_with_snapshot_support_without_cg(self, microversion):
         self.mock_object(share_api.API, 'create', self.create_mock)
         body = {"share": copy.deepcopy(self.share)}
-        req = fakes.HTTPRequest.blank('/shares', version=microversion)
+        req = fakes.HTTPRequest.blank('/v1/fake/shares', version=microversion)
 
         res_dict = self.controller.create(req, body)
 
@@ -173,7 +172,7 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'create', self.create_mock)
 
         body = {"share": copy.deepcopy(self.share)}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
         res_dict = self.controller.create(req, body)
 
         self.mock_policy_check.assert_called_once_with(
@@ -191,7 +190,7 @@ class ShareAPITest(test.TestCase):
                 self.vt['name'])),
         )
         CONF.set_default("default_share_type", self.vt['name'])
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
 
         self.assertRaises(exception.ShareTypeNotFoundByName,
                           self.controller.create, req, {'share': self.share})
@@ -212,7 +211,7 @@ class ShareAPITest(test.TestCase):
             mock.Mock(return_value=fake_share_type),
         )
         CONF.set_default("default_share_type", fake_share_type['name'])
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create, req, {'share': self.share})
@@ -229,6 +228,7 @@ class ShareAPITest(test.TestCase):
             "availability_zone": "zone1:host1",
             "share_network_id": "fakenetid"
         }
+        fake_network = {'id': 'fakenetid'}
         create_mock = mock.Mock(return_value=stubs.stub_share('1',
                                 display_name=shr['name'],
                                 display_description=shr['description'],
@@ -238,21 +238,65 @@ class ShareAPITest(test.TestCase):
                                 share_network_id=shr['share_network_id']))
         self.mock_object(share_api.API, 'create', create_mock)
         self.mock_object(share_api.API, 'get_share_network', mock.Mock(
-            return_value={'id': 'fakenetid'}))
+            return_value=fake_network))
+        self.mock_object(common, 'check_share_network_is_active',
+                         mock.Mock(return_value=True))
+        self.mock_object(
+            db, 'share_network_subnet_get_by_availability_zone_id',
+            mock.Mock(return_value={'id': 'fakesubnetid'}))
 
         body = {"share": copy.deepcopy(shr)}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
         res_dict = self.controller.create(req, body)
 
         self.mock_policy_check.assert_called_once_with(
             req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
+        common.check_share_network_is_active.assert_called_once_with(
+            fake_network)
         self.assertEqual(expected, res_dict)
         # pylint: disable=unsubscriptable-object
         self.assertEqual("fakenetid",
                          create_mock.call_args[1]['share_network_id'])
 
+    def test_share_create_with_share_net_not_active(self):
+        shr = {
+            "size": 100,
+            "name": "Share Test Name",
+            "description": "Share Test Desc",
+            "share_proto": "fakeproto",
+            "availability_zone": "zone1:host1",
+            "share_network_id": "fakenetid"
+        }
+        share_network = db_utils.create_share_network(
+            status=constants.STATUS_NETWORK_CHANGE)
+        create_mock = mock.Mock(return_value=stubs.stub_share('1',
+                                display_name=shr['name'],
+                                display_description=shr['description'],
+                                size=shr['size'],
+                                share_proto=shr['share_proto'].upper(),
+                                availability_zone=shr['availability_zone'],
+                                share_network_id=shr['share_network_id']))
+        self.mock_object(share_api.API, 'create', create_mock)
+        self.mock_object(share_api.API, 'get_share_network', mock.Mock(
+            return_value=share_network))
+        self.mock_object(common, 'check_share_network_is_active',
+                         mock.Mock(side_effect=webob.exc.HTTPBadRequest()))
+
+        body = {"share": copy.deepcopy(shr)}
+        req = fakes.HTTPRequest.blank('/shares')
+        self.assertRaises(
+            webob.exc.HTTPBadRequest,
+            self.controller.create,
+            req,
+            body)
+
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], self.resource_name, 'create')
+        common.check_share_network_is_active.assert_called_once_with(
+            share_network)
+
     def test_share_create_from_snapshot_without_share_net_no_parent(self):
         shr = {
             "size": 100,
@@ -273,7 +317,7 @@ class ShareAPITest(test.TestCase):
                                 share_network_id=shr['share_network_id']))
         self.mock_object(share_api.API, 'create', create_mock)
         body = {"share": copy.deepcopy(shr)}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
 
         res_dict = self.controller.create(req, body)
 
@@ -294,6 +338,7 @@ class ShareAPITest(test.TestCase):
             "share_network_id": None,
         }
         parent_share_net = 444
+        fake_share_net = {'id': parent_share_net}
         create_mock = mock.Mock(return_value=stubs.stub_share('1',
                                 display_name=shr['name'],
                                 display_description=shr['description'],
@@ -312,10 +357,14 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'get', mock.Mock(
             return_value=parent_share))
         self.mock_object(share_api.API, 'get_share_network', mock.Mock(
-            return_value={'id': parent_share_net}))
+            return_value=fake_share_net))
+        self.mock_object(common, 'check_share_network_is_active',
+                         mock.Mock(return_value=True))
+        self.mock_object(
+            db, 'share_network_subnet_get_by_availability_zone_id')
 
         body = {"share": copy.deepcopy(shr)}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
 
         res_dict = self.controller.create(req, body)
 
@@ -323,6 +372,8 @@ class ShareAPITest(test.TestCase):
             req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
+        common.check_share_network_is_active.assert_called_once_with(
+            fake_share_net)
         self.assertEqual(expected, res_dict)
         # pylint: disable=unsubscriptable-object
         self.assertEqual(parent_share_net,
@@ -339,6 +390,7 @@ class ShareAPITest(test.TestCase):
             "snapshot_id": 333,
             "share_network_id": parent_share_net
         }
+        fake_share_net = {'id': parent_share_net}
         create_mock = mock.Mock(return_value=stubs.stub_share('1',
                                 display_name=shr['name'],
                                 display_description=shr['description'],
@@ -351,16 +403,20 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'create', create_mock)
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get)
+        self.mock_object(common, 'check_share_network_is_active',
+                         mock.Mock(return_value=True))
         parent_share = stubs.stub_share(
             '1', instance={'share_network_id': parent_share_net},
             create_share_from_snapshot_support=True)
         self.mock_object(share_api.API, 'get', mock.Mock(
             return_value=parent_share))
         self.mock_object(share_api.API, 'get_share_network', mock.Mock(
-            return_value={'id': parent_share_net}))
+            return_value=fake_share_net))
+        self.mock_object(
+            db, 'share_network_subnet_get_by_availability_zone_id')
 
         body = {"share": copy.deepcopy(shr)}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
 
         res_dict = self.controller.create(req, body)
 
@@ -368,6 +424,8 @@ class ShareAPITest(test.TestCase):
             req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
+        common.check_share_network_is_active.assert_called_once_with(
+            fake_share_net)
         self.assertEqual(expected, res_dict)
         # pylint: disable=unsubscriptable-object
         self.assertEqual(parent_share_net,
@@ -385,7 +443,7 @@ class ShareAPITest(test.TestCase):
             "share_network_id": 1234
         }
         body = {"share": shr}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/v1/fake/shares')
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.create,
@@ -409,6 +467,7 @@ class ShareAPITest(test.TestCase):
             "snapshot_id": 333,
             "share_network_id": parent_share_net
         }
+        fake_share_net = {'id': parent_share_net}
         create_mock = mock.Mock(return_value=stubs.stub_share('1',
                                 display_name=shr['name'],
                                 display_description=shr['description'],
@@ -421,16 +480,20 @@ class ShareAPITest(test.TestCase):
         self.mock_object(share_api.API, 'create', create_mock)
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get)
+        self.mock_object(common, 'check_share_network_is_active',
+                         mock.Mock(return_value=True))
         parent_share = stubs.stub_share(
             '1', instance={'share_network_id': parent_share_net},
             create_share_from_snapshot_support=False)
         self.mock_object(share_api.API, 'get', mock.Mock(
             return_value=parent_share))
         self.mock_object(share_api.API, 'get_share_network', mock.Mock(
-            return_value={'id': parent_share_net}))
+            return_value=fake_share_net))
+        self.mock_object(
+            db, 'share_network_subnet_get_by_availability_zone_id')
 
         body = {"share": copy.deepcopy(shr)}
-        req = fakes.HTTPRequest.blank('/shares', version=microversion)
+        req = fakes.HTTPRequest.blank('/v1/fake/shares', version=microversion)
 
         res_dict = self.controller.create(req, body)
 
@@ -438,6 +501,8 @@ class ShareAPITest(test.TestCase):
             req.environ['manila.context'], self.resource_name, 'create')
         expected = self._get_expected_share_detailed_response(shr)
         expected['share'].pop('snapshot_support')
+        common.check_share_network_is_active.assert_called_once_with(
+            fake_share_net)
         self.assertDictEqual(expected, res_dict)
         # pylint: disable=unsubscriptable-object
         self.assertEqual(parent_share_net,
@@ -450,7 +515,7 @@ class ShareAPITest(test.TestCase):
                "share_proto": "fakeproto",
                "availability_zone": "zone1:host1"}
         body = {"share": shr}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/fake/shares')
         self.assertRaises(exception.InvalidInput,
                           self.controller.create,
                           req,
@@ -460,7 +525,7 @@ class ShareAPITest(test.TestCase):
 
     def test_share_create_no_body(self):
         body = {}
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/fake/shares')
         self.assertRaises(webob.exc.HTTPUnprocessableEntity,
                           self.controller.create,
                           req,
@@ -476,14 +541,37 @@ class ShareAPITest(test.TestCase):
         )
         body = {"share": copy.deepcopy(self.share)}
 
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/fake/shares')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.create,
                           req,
                           body)
 
+    @ddt.data((exception.ShareNetworkNotFound(share_network_id='fake'),
+               webob.exc.HTTPNotFound),
+              (mock.Mock(), webob.exc.HTTPBadRequest))
+    @ddt.unpack
+    def test_share_create_invalid_subnet(self, share_network_side_effect,
+                                         exception_to_raise):
+        fake_share_with_sn = copy.deepcopy(self.share)
+        fake_share_with_sn['share_network_id'] = 'fakenetid'
+        self.mock_object(db, 'share_network_get',
+                         mock.Mock(side_effect=share_network_side_effect))
+        self.mock_object(
+            db, 'share_network_subnet_get_by_availability_zone_id',
+            mock.Mock(return_value=None))
+        self.mock_object(common, 'check_share_network_is_active')
+
+        body = {"share": fake_share_with_sn}
+
+        req = fakes.HTTPRequest.blank('/fake/shares')
+        self.assertRaises(exception_to_raise,
+                          self.controller.create,
+                          req,
+                          body)
+
     def test_share_show(self):
-        req = fakes.HTTPRequest.blank('/shares/1')
+        req = fakes.HTTPRequest.blank('/fake/shares/1')
         expected = self._get_expected_share_detailed_response()
         expected['share'].pop('snapshot_support')
 
@@ -492,7 +580,7 @@ class ShareAPITest(test.TestCase):
         self.assertEqual(expected, res_dict)
 
     def test_share_show_with_share_type_name(self):
-        req = fakes.HTTPRequest.blank('/shares/1', version='2.6')
+        req = fakes.HTTPRequest.blank('/fake/shares/1', version='2.6')
         res_dict = self.controller.show(req, '1')
         expected = self._get_expected_share_detailed_response()
         expected['share']['share_type_name'] = None
@@ -500,7 +588,7 @@ class ShareAPITest(test.TestCase):
         self.assertEqual(expected, res_dict)
 
     def test_share_show_admin(self):
-        req = fakes.HTTPRequest.blank('/shares/1', use_admin_context=True)
+        req = fakes.HTTPRequest.blank('/fake/shares/1', use_admin_context=True)
         expected = self._get_expected_share_detailed_response(admin=True)
         expected['share'].pop('snapshot_support')
 
@@ -511,13 +599,13 @@ class ShareAPITest(test.TestCase):
     def test_share_show_no_share(self):
         self.mock_object(share_api.API, 'get',
                          stubs.stub_share_get_notfound)
-        req = fakes.HTTPRequest.blank('/shares/1')
+        req = fakes.HTTPRequest.blank('/fake/shares/1')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show,
                           req, '1')
 
     def test_share_delete(self):
-        req = fakes.HTTPRequest.blank('/shares/1')
+        req = fakes.HTTPRequest.blank('/fake/shares/1')
         resp = self.controller.delete(req, 1)
         self.assertEqual(202, resp.status_int)
 
@@ -549,7 +637,7 @@ class ShareAPITest(test.TestCase):
     def test_share_delete_no_share(self):
         self.mock_object(share_api.API, 'get',
                          stubs.stub_share_get_notfound)
-        req = fakes.HTTPRequest.blank('/shares/1')
+        req = fakes.HTTPRequest.blank('/fake/shares/1')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.delete,
                           req,
@@ -574,7 +662,7 @@ class ShareAPITest(test.TestCase):
         if use_admin_context:
             search_opts['host'] = 'fake_host'
         # fake_key should be filtered for non-admin
-        url = '/shares?fake_key=fake_value'
+        url = '/fake/shares?fake_key=fake_value'
         for k, v in search_opts.items():
             url = url + '&' + k + '=' + v
         req = fakes.HTTPRequest.blank(url, use_admin_context=use_admin_context)
@@ -626,7 +714,7 @@ class ShareAPITest(test.TestCase):
     def test_share_list_summary(self):
         self.mock_object(share_api.API, 'get_all',
                          stubs.stub_share_get_all_by_project)
-        req = fakes.HTTPRequest.blank('/shares')
+        req = fakes.HTTPRequest.blank('/fake/shares')
         res_dict = self.controller.index(req)
         expected = {
             'shares': [
@@ -635,11 +723,11 @@ class ShareAPITest(test.TestCase):
                     'id': '1',
                     'links': [
                         {
-                            'href': 'http://localhost/v1/fake/shares/1',
+                            'href': 'http://localhost/share/v1/fake/shares/1',
                             'rel': 'self'
                         },
                         {
-                            'href': 'http://localhost/fake/shares/1',
+                            'href': 'http://localhost/share/fake/shares/1',
                             'rel': 'bookmark'
                         }
                     ],
@@ -667,7 +755,7 @@ class ShareAPITest(test.TestCase):
         if use_admin_context:
             search_opts['host'] = 'fake_host'
         # fake_key should be filtered for non-admin
-        url = '/shares/detail?fake_key=fake_value'
+        url = '/fake/shares/detail?fake_key=fake_value'
         for k, v in search_opts.items():
             url = url + '&' + k + '=' + v
         req = fakes.HTTPRequest.blank(url, use_admin_context=use_admin_context)
@@ -761,11 +849,11 @@ class ShareAPITest(test.TestCase):
             'is_public': False,
             'links': [
                 {
-                    'href': 'http://localhost/v1/fake/shares/1',
+                    'href': 'http://localhost/share/v1/fake/shares/1',
                     'rel': 'self'
                 },
                 {
-                    'href': 'http://localhost/fake/shares/1',
+                    'href': 'http://localhost/share/fake/shares/1',
                     'rel': 'bookmark'
                 }
             ],
@@ -784,14 +872,14 @@ class ShareAPITest(test.TestCase):
 
     def test_share_list_detail(self):
         env = {'QUERY_STRING': 'name=Share+Test+Name'}
-        req = fakes.HTTPRequest.blank('/shares/detail', environ=env)
+        req = fakes.HTTPRequest.blank('/fake/shares/detail', environ=env)
         expected = self._list_detail_common_expected()
         expected['shares'][0].pop('snapshot_support')
         self._list_detail_test_common(req, expected)
 
     def test_share_list_detail_with_task_state(self):
         env = {'QUERY_STRING': 'name=Share+Test+Name'}
-        req = fakes.HTTPRequest.blank('/shares/detail', environ=env,
+        req = fakes.HTTPRequest.blank('/fake/shares/detail', environ=env,
                                       version="2.5")
         expected = self._list_detail_common_expected()
         expected['shares'][0]['task_state'] = None
@@ -862,6 +950,29 @@ class ShareActionsTest(test.TestCase):
                          mock.Mock(return_value={'access':
                                                  {'fake': 'fake'}}))
 
+        id = 'fake_share_id'
+        body = {'os-allow_access': access}
+        expected = {'access': {'fake': 'fake'}}
+        req = fakes.HTTPRequest.blank('/tenant1/shares/%s/action' % id)
+
+        res = self.controller._allow_access(req, id, body)
+
+        self.assertEqual(expected, res)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], 'share', 'allow_access')
+
+    def test_allow_access_with_network_id(self):
+        share_network = db_utils.create_share_network()
+        share = db_utils.create_share(share_network_id=share_network['id'])
+        access = {'access_type': 'user', 'access_to': '1' * 4}
+
+        self.mock_object(share_api.API,
+                         'allow_access',
+                         mock.Mock(return_value={'fake': 'fake'}))
+        self.mock_object(self.controller._access_view_builder, 'view',
+                         mock.Mock(return_value={'access': {'fake': 'fake'}}))
+        self.mock_object(share_api.API, 'get', mock.Mock(return_value=share))
+
         id = 'fake_share_id'
         body = {'os-allow_access': access}
         expected = {'access': {'fake': 'fake'}}
@@ -893,7 +1004,7 @@ class ShareActionsTest(test.TestCase):
     def test_allow_access_error(self, access):
         id = 'fake_share_id'
         body = {'os-allow_access': access}
-        req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/tenant1/shares/%s/action' % id)
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller._allow_access, req, id, body)
@@ -907,6 +1018,23 @@ class ShareActionsTest(test.TestCase):
         self.mock_object(share_api.API, "deny_access", _stub_deny_access)
         self.mock_object(share_api.API, "access_get", _fake_access_get)
 
+        id = 'fake_share_id'
+        body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
+        req = fakes.HTTPRequest.blank('/tenant1/shares/%s/action' % id)
+
+        res = self.controller._deny_access(req, id, body)
+
+        self.assertEqual(202, res.status_int)
+        self.mock_policy_check.assert_called_once_with(
+            req.environ['manila.context'], 'share', 'deny_access')
+
+    def test_deny_access_with_share_network_id(self):
+        self.mock_object(share_api.API, "deny_access", mock.Mock())
+        self.mock_object(share_api.API, "access_get", _fake_access_get)
+        share_network = db_utils.create_share_network()
+        share = db_utils.create_share(share_network_id=share_network['id'])
+        self.mock_object(share_api.API, 'get', mock.Mock(return_value=share))
+
         id = 'fake_share_id'
         body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
         req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
@@ -926,7 +1054,7 @@ class ShareActionsTest(test.TestCase):
 
         id = 'super_fake_share_id'
         body = {"os-deny_access": {"access_id": 'fake_acces_id'}}
-        req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/tenant1/shares/%s/action' % id)
 
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller._deny_access,
@@ -938,7 +1066,7 @@ class ShareActionsTest(test.TestCase):
 
     @ddt.data('_allow_access', '_deny_access')
     def test_allow_access_deny_access_policy_not_authorized(self, method):
-        req = fakes.HTTPRequest.blank('/v1/tenant1/shares/someuuid/action')
+        req = fakes.HTTPRequest.blank('/tenant1/shares/someuuid/action')
         action = method[1:]
         body = {action: None}
         noauthexc = exception.PolicyNotAuthorized(action=action)
@@ -965,7 +1093,7 @@ class ShareActionsTest(test.TestCase):
                                                  fake_access_list}))
         id = 'fake_share_id'
         body = {"os-access_list": None}
-        req = fakes.HTTPRequest.blank('/v1/tenant1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/tenant1/shares/%s/action' % id)
 
         res_dict = self.controller._access_list(req, id, body)
         self.assertEqual({'access_list': fake_access_list}, res_dict)
@@ -978,7 +1106,7 @@ class ShareActionsTest(test.TestCase):
 
         size = '123'
         body = {"os-extend": {'new_size': size}}
-        req = fakes.HTTPRequest.blank('/v1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/fake/shares/%s/action' % id)
 
         actual_response = self.controller._extend(req, id, body)
 
@@ -992,7 +1120,7 @@ class ShareActionsTest(test.TestCase):
               {"os-extend": {"new_size": {'foo': 'bar'}}})
     def test_extend_invalid_body(self, body):
         id = 'fake_share_id'
-        req = fakes.HTTPRequest.blank('/v1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/fake/shares/%s/action' % id)
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller._extend, req, id, body)
@@ -1006,7 +1134,7 @@ class ShareActionsTest(test.TestCase):
     @ddt.unpack
     def test_extend_exception(self, source, target):
         id = 'fake_share_id'
-        req = fakes.HTTPRequest.blank('/v1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/fake/shares/%s/action' % id)
         body = {"os-extend": {'new_size': '123'}}
         self.mock_object(share_api.API, "extend",
                          mock.Mock(side_effect=source('fake')))
@@ -1021,7 +1149,7 @@ class ShareActionsTest(test.TestCase):
 
         size = '123'
         body = {"os-shrink": {'new_size': size}}
-        req = fakes.HTTPRequest.blank('/v1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/fake/shares/%s/action' % id)
 
         actual_response = self.controller._shrink(req, id, body)
 
@@ -1035,7 +1163,7 @@ class ShareActionsTest(test.TestCase):
               {"os-shrink": {"new_size": {'foo': 'bar'}}})
     def test_shrink_invalid_body(self, body):
         id = 'fake_share_id'
-        req = fakes.HTTPRequest.blank('/v1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/fake/shares/%s/action' % id)
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller._shrink, req, id, body)
@@ -1047,7 +1175,7 @@ class ShareActionsTest(test.TestCase):
     @ddt.unpack
     def test_shrink_exception(self, source, target):
         id = 'fake_share_id'
-        req = fakes.HTTPRequest.blank('/v1/shares/%s/action' % id)
+        req = fakes.HTTPRequest.blank('/fake/shares/%s/action' % id)
         body = {"os-shrink": {'new_size': '123'}}
         self.mock_object(share_api.API, "shrink",
                          mock.Mock(side_effect=source('fake')))
@@ -1083,7 +1211,7 @@ class ShareAdminActionsAPITest(test.TestCase):
             body = {'os-reset_status': {'status': constants.STATUS_ERROR}}
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         resp = req.get_response(fakes.app())
@@ -1131,7 +1259,7 @@ class ShareAdminActionsAPITest(test.TestCase):
 
     def test_share_reset_status_for_missing(self):
         fake_share = {'id': 'missing-share-id'}
-        req = webob.Request.blank('/v1/fake/shares/%s/action' %
+        req = webob.Request.blank('/fake/shares/%s/action' %
                                   fake_share['id'])
 
         self._reset_status(self.admin_context, fake_share, req,
@@ -1141,7 +1269,7 @@ class ShareAdminActionsAPITest(test.TestCase):
                       check_model_in_db=False):
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
-        req.body = six.b(jsonutils.dumps({'os-force_delete': {}}))
+        req.body = jsonutils.dumps({'os-force_delete': {}}).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         resp = req.get_response(fakes.app())
