@@ -230,6 +230,7 @@ class FakeHostManager(host_manager.HostManager):
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'writable',
                       'replication_domain': 'endor',
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host2': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 300,
@@ -243,6 +244,7 @@ class FakeHostManager(host_manager.HostManager):
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'readable',
                       'replication_domain': 'kashyyyk',
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host3': {'total_capacity_gb': 512,
                       'free_capacity_gb': 256,
@@ -254,6 +256,7 @@ class FakeHostManager(host_manager.HostManager):
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host4': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 200,
@@ -267,6 +270,7 @@ class FakeHostManager(host_manager.HostManager):
                       'create_share_from_snapshot_support': True,
                       'replication_type': 'dr',
                       'replication_domain': 'naboo',
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host5': {'total_capacity_gb': 2048,
                       'free_capacity_gb': 500,
@@ -279,6 +283,7 @@ class FakeHostManager(host_manager.HostManager):
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'replication_type': None,
+                      'storage_protocol': 'NFS_CIFS',
                       },
             'host6': {'total_capacity_gb': 'unknown',
                       'free_capacity_gb': 'unknown',
@@ -288,6 +293,7 @@ class FakeHostManager(host_manager.HostManager):
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
+                      'storage_protocol': 'GLUSTERFS',
                       },
         }
 
@@ -298,6 +304,7 @@ class FakeHostState(host_manager.HostState):
         for (key, val) in attribute_dict.items():
             setattr(self, key, val)
 
+
 FAKE_HOST_STRING_1 = 'openstack@BackendA#PoolX'
 FAKE_HOST_STRING_2 = 'openstack@BackendB#PoolY'
 FAKE_HOST_STRING_3 = 'openstack@BackendC#PoolZ'
